@@ -60,11 +60,12 @@ class Freebox(IPlugin):
 				log.msg("BODIES  :  %s" % (bodies))
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
-					# séparation de rs['idx'], nombre   len(maliste)  
-					for rang in range(len(rs['idx']))
-						if rs['idx'][rang] == '|':
-							rangs.append(rang)
-							log.msg(" rang  :  %s" % (rangs)
+					# séparation de rs['idx'], nombre   len(maliste)
+	# ###   140826			i = 1
+					while i <= int(rs['idx_sec']): 
+		#				if rs['idx'][i - rang] == '|':
+						rangs.append(rang)
+						log.msg(" rang  :  %s" % (rangs)
 #>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
 #...     if mot[rang] == 'i':
 #...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
